@@ -11,9 +11,8 @@ from disjoint_set import DisjointSet
 import networkx as nx
 import itertools
 from scipy.special import logsumexp
-from snsynth.cdp2adp import cdp_rho
 from snsynth.base import Synthesizer
-from snsynth.utils import gaussian_noise
+from snsynth.utils import cdp_rho, gaussian_noise
 
 """
 Wrapper for MST synthesizer from Private PGM:
@@ -142,7 +141,6 @@ class MSTSynthesizer(Synthesizer):
         for proj, wgt in zip(cliques, weights):
             x = data.project(proj).datavector()
             y = x + gaussian_noise(sigma/wgt, x.size)
-            # y = x + np.random.normal(loc=0, scale=sigma/wgt, size=x.size)
             Q = sparse.eye(x.size)
             measurements.append((Q, y, sigma/wgt, proj))
         return measurements
