@@ -8,6 +8,7 @@ import numpy as np
 import pandas as pd
 
 from snsynth.base import Synthesizer
+from snsynth.utils import laplace_noise
 
 class Query:
     def __init__(self, query):
@@ -343,8 +344,7 @@ class MWEMSynthesizer(Synthesizer):
             self.split_factor = self.data.shape[1]
             self.splits = self._generate_splits(self.data.T.shape[0], self.split_factor)
 
-        self.splits = np.array(self.splits)
-        if self.splits.size == 0:
+        if len(self.splits) == 0:
             self.histograms = self._histogram_from_data_attributes(
                 self.data, [np.arange(self.data.shape[1])]
             )
@@ -392,7 +392,10 @@ class MWEMSynthesizer(Synthesizer):
                 print(f"Columns: {h.n_cols}")
                 print(f"Dimensionality: {h.dimensionality:,}")
                 print(f"Cuboids possible: {h.n_cuboids}")
-                print(f"1-2-way cuboids possible: {math.comb(h.n_cols, 2) + h.n_cols}")
+                if hasattr(math, "comb"):
+                    print(f"1-2-way cuboids possible: {math.comb(h.n_cols, 2) + h.n_cols}")
+                elif hasattr(math, "factorial"):
+                    print(f"1-2-way cuboids possible: {(math.factorial(h.n_cols) // math.factorial(2) // math.factorial(h.n_cols - 2)) + h.n_cols}")
                 print(f"Fitting for {h.iterations} iterations")
                 print(f"Number of queries: {h.n_queries}")
                 print(f"Number of slices in queries: {h.n_slices}")
@@ -690,7 +693,7 @@ class MWEMSynthesizer(Synthesizer):
         :return: 2d list with splits (column indices)
         :rtype: array of arrays
         """
-        flat = np.concatenate(np.asarray(splits)).ravel()
+        flat = [i for l in splits for i in l]
         reordered = np.zeros(len(flat))
         for i, ind in enumerate(flat):
             reordered[ind] = i
@@ -719,7 +722,7 @@ class MWEMSynthesizer(Synthesizer):
         if indices[fits:].size != 0:
             s1.append(indices[fits:])
         s2 = [np.array(l_val) for l_val in s1]
-        return np.array(s2)
+        return s2
 
     def _laplace(self, sigma):
         """
@@ -730,4 +733,4 @@ class MWEMSynthesizer(Synthesizer):
         :return: Random value from laplace distribution [-1,1]
         :rtype: float
         """
-        return sigma * np.log(random.random()) * np.random.choice([-1, 1])
+        return laplace_noise(sigma)
